%global         forgeurl        https://github.com/DrTimothyAldenDavis/GraphBLAS
Version:        8.3.1
%global         tag             v%{version}
%forgemeta

Name:           suitesparse-graphblas
Release:        1%{?dist}
Summary:        Graph algorithms in the language of linear algebra

License:        Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause
URL:            %forgeurl
Source0:        %{url}/archive/v%{version}/graphblas-%{version}.tar.gz


BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-gfortran
# https://github.com/DrTimothyAldenDavis/GraphBLAS/issues/233
Provides:       bundled(lz4)
Provides:       bundled(xxhash)
Provides:       bundled(zstd)

%global _description %{expand:
SuiteSparse:GraphBLAS is a complete implementation of the GraphBLAS
standard, which defines a set of sparse matrix operations on an
extended algebra of semirings using an almost unlimited variety of
operators and types. When applied to sparse adjacency matrices,
these algebraic operations are equivalent to computations on graphs.
GraphBLAS provides a powerful and expressive framework for creating
graph algorithms based on the elegant mathematics of sparse matrix
operations on a semiring.

SuiteSparse:GraphBLAS is used heavily in production. It appears as
the underlying graph engine in the RedisGraph database by Redis,
and as the built-in sparse matrix multiply in MATLAB R2021a, where
C=A*B is now up to 30x faster than in prior versions of MATLAB (on
my 20-core NVIDIA DGX Station).

The development of this package is supported by Intel, NVIDIA
(including the donation of the 20-core DGX Station), Redis,
MIT Lincoln Lab, MathWorks, IBM, and Julia Computing.}

%description %_description

%package doc
Summary:    Documentation for GraphBLAS
BuildArch:  noarch

%description doc %_description

%package devel
Summary:    Development header file and shared library
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel %_description


%prep
%autosetup -n GraphBLAS-%{version}
rm -r rmm_wrap

%build
%cmake -DSUITESPARSE_DEMOS=1 -DLOCAL_INSTALL=OFF  \
       -DSUITESPARSE_CUDA=OFF -DSUITESPARSE_OPENMP=ON \
       -DSUITESPARSE_USE_FORTRAN=ON -DGRAPHBLAS_USE_OPENMP=ON \
       -DGRAPHBLAS_USE_JIT=ON -DBUILD_SHARED_LIBS=ON 
%cmake_build

%install
%cmake_install

%check
# Run some of the demos as a
# smoke test
make demos

%files
%license LICENSE
%doc README.md
%doc CITATION.bib
%{_libdir}/libgraphblas.so.8*

%files doc
%license LICENSE
%doc Doc/*.pdf

%files devel
%dir %{_includedir}/suitesparse
%{_includedir}/suitesparse/GraphBLAS.h
%dir %{_libdir}/cmake/GraphBLAS
%{_libdir}/cmake/GraphBLAS/*.cmake
%{_libdir}/libgraphblas.so
%{_libdir}/pkgconfig/GraphBLAS.pc

%changelog
* Sun Jan 07 2024 Benson Muite <benson_muite@emailplus.org> - 8.3.1-1
- Update to latest release

* Sat Sep 09 2023 Benson Muite <benson_muite@emailplus.org> - 8.2.0-1
- Initial package
